@@ -1,4 +1,4 @@
-import os
+import subprocess
 
 from .deployer import Deployer
 from .models import DeployConfig
@@ -10,9 +10,9 @@ class CloudFunctions(Deployer):
         options = " ".join([f"{key} {value}" for key, value in config.options.items()])
         cmd = (f"cd {self.source_directory} && "
                f"gcloud functions deploy {config.name} "
-               f"--runtime python37 "
-               f"--trigger-http "
-               f"--entry-point entry_point "
-               f"--set-env-vars PLATFORM=GCP ")
+               "--runtime python37 "
+               "--trigger-http "
+               "--entry-point entry_point "
+               "--set-env-vars PLATFORM=GCP ")
         cmd += options
-        os.system(cmd)
+        subprocess.run(cmd, shell=True, check=True)
